Assets class
Asset paths for built-in GIF hint animations used during liveness challenges.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- gifBlink → const String
- Path to the eye-blink hint GIF shown during a blink challenge.
- gifNod → const String
- Path to the head-nod hint GIF shown during a nod challenge.
- gifRotateLeft → const String
- Path to the rotate-left hint GIF shown during a turn-left challenge.
- gifRotateRight → const String
- Path to the rotate-right hint GIF shown during a turn-right challenge.
- gifSmile → const String
- Path to the smile hint GIF shown during a smile challenge.